@@ -19,9 +19,16 @@ class Headers:
             "Accept-Encoding": "gzip",
             "Connection": "Keep-Alive"
         }
+        self.web_headers = {
+            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36",
+            "x-requested-with": "xmlhttprequest"
+        }
 
         if data: headers["Content-Length"] = str(len(data))
-        if sid: headers["NDCAUTH"] = f"sid={sid}"
+        if sid:
+            headers["NDCAUTH"] = f"sid={sid}"
+            self.web_headers["cookie"] = f"sid={sid}"
         if type: headers["Content-Type"] = type
         #if sig: headers["NDC-MSG-SIG"] = sig
         self.headers = headers
+        #print(sid)
